==> huaweicloudsdkmetastudio-3.1.72-py2.py3-none-any.whl: huaweicloudsdkmetastudio/v1/model/update_video_script_request.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class UpdateVideoScriptRequest:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'x_app_user_id': 'str',
        'script_id': 'str',
        'body': 'UpdateVideoScriptsReq'
    }

    attribute_map = {
        'x_app_user_id': 'X-App-UserId',
        'script_id': 'script_id',
        'body': 'body'
    }

    def __init__(self, x_app_user_id=None, script_id=None, body=None):
        """UpdateVideoScriptRequest

        The model defined in huaweicloud sdk

        :param x_app_user_id: 开发者应用作为资产权属的可选字段。
        :type x_app_user_id: str
        :param script_id: 剧本ID。
        :type script_id: str
        :param body: Body of the UpdateVideoScriptRequest
        :type body: :class:`huaweicloudsdkmetastudio.v1.UpdateVideoScriptsReq`
        """
        
        

        self._x_app_user_id = None
        self._script_id = None
        self._body = None
        self.discriminator = None

        if x_app_user_id is not None:
            self.x_app_user_id = x_app_user_id
        self.script_id = script_id
        if body is not None:
            self.body = body

    @property
    def x_app_user_id(self):
        """Gets the x_app_user_id of this UpdateVideoScriptRequest.

        开发者应用作为资产权属的可选字段。

        :return: The x_app_user_id of this UpdateVideoScriptRequest.
        :rtype: str
        """
        return self._x_app_user_id

    @x_app_user_id.setter
    def x_app_user_id(self, x_app_user_id):
        """Sets the x_app_user_id of this UpdateVideoScriptRequest.

        开发者应用作为资产权属的可选字段。

        :param x_app_user_id: The x_app_user_id of this UpdateVideoScriptRequest.
        :type x_app_user_id: str
        """
        self._x_app_user_id = x_app_user_id

    @property
    def script_id(self):
        """Gets the script_id of this UpdateVideoScriptRequest.

        剧本ID。

        :return: The script_id of this UpdateVideoScriptRequest.
        :rtype: str
        """
        return self._script_id

    @script_id.setter
    def script_id(self, script_id):
        """Sets the script_id of this UpdateVideoScriptRequest.

        剧本ID。

        :param script_id: The script_id of this UpdateVideoScriptRequest.
        :type script_id: str
        """
        self._script_id = script_id

    @property
    def body(self):
        """Gets the body of this UpdateVideoScriptRequest.

        :return: The body of this UpdateVideoScriptRequest.
        :rtype: :class:`huaweicloudsdkmetastudio.v1.UpdateVideoScriptsReq`
        """
        return self._body

    @body.setter
    def body(self, body):
        """Sets the body of this UpdateVideoScriptRequest.

        :param body: The body of this UpdateVideoScriptRequest.
        :type body: :class:`huaweicloudsdkmetastudio.v1.UpdateVideoScriptsReq`
        """
        self._body = body

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, UpdateVideoScriptRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkmetastudio-3.1.77-py2.py3-none-any.whl: huaweicloudsdkmetastudio/v1/model/update_video_script_request.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class UpdateVideoScriptRequest:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'x_app_user_id': 'str',
        'script_id': 'str',
        'body': 'UpdateVideoScriptsReq'
    }

    attribute_map = {
        'x_app_user_id': 'X-App-UserId',
        'script_id': 'script_id',
        'body': 'body'
    }

    def __init__(self, x_app_user_id=None, script_id=None, body=None):
        """UpdateVideoScriptRequest

        The model defined in huaweicloud sdk

        :param x_app_user_id: 第三方用户ID。 &gt; *不允许输入中文。
        :type x_app_user_id: str
        :param script_id: 剧本ID。
        :type script_id: str
        :param body: Body of the UpdateVideoScriptRequest
        :type body: :class:`huaweicloudsdkmetastudio.v1.UpdateVideoScriptsReq`
        """
        
        

        self._x_app_user_id = None
        self._script_id = None
        self._body = None
        self.discriminator = None

        if x_app_user_id is not None:
            self.x_app_user_id = x_app_user_id
        self.script_id = script_id
        if body is not None:
            self.body = body

    @property
    def x_app_user_id(self):
        """Gets the x_app_user_id of this UpdateVideoScriptRequest.

        第三方用户ID。 > *不允许输入中文。

        :return: The x_app_user_id of this UpdateVideoScriptRequest.
        :rtype: str
        """
        return self._x_app_user_id

    @x_app_user_id.setter
    def x_app_user_id(self, x_app_user_id):
        """Sets the x_app_user_id of this UpdateVideoScriptRequest.

        第三方用户ID。 > *不允许输入中文。

        :param x_app_user_id: The x_app_user_id of this UpdateVideoScriptRequest.
        :type x_app_user_id: str
        """
        self._x_app_user_id = x_app_user_id

    @property
    def script_id(self):
        """Gets the script_id of this UpdateVideoScriptRequest.

        剧本ID。

        :return: The script_id of this UpdateVideoScriptRequest.
        :rtype: str
        """
        return self._script_id

    @script_id.setter
    def script_id(self, script_id):
        """Sets the script_id of this UpdateVideoScriptRequest.

        剧本ID。

        :param script_id: The script_id of this UpdateVideoScriptRequest.
        :type script_id: str
        """
        self._script_id = script_id

    @property
    def body(self):
        """Gets the body of this UpdateVideoScriptRequest.

        :return: The body of this UpdateVideoScriptRequest.
        :rtype: :class:`huaweicloudsdkmetastudio.v1.UpdateVideoScriptsReq`
        """
        return self._body

    @body.setter
    def body(self, body):
        """Sets the body of this UpdateVideoScriptRequest.

        :param body: The body of this UpdateVideoScriptRequest.
        :type body: :class:`huaweicloudsdkmetastudio.v1.UpdateVideoScriptsReq`
        """
        self._body = body

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, UpdateVideoScriptRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
